@@ -132,9 +132,14 @@ clutter_animation_real_completed (ClutterAnimation *self)
 {
   ClutterAnimationPrivate *priv = self->priv;
   ClutterAnimation *animation;
+  ClutterTimeline *timeline;
+  ClutterTimelineDirection direction;
   gpointer key, value;
   GHashTableIter iter;
 
+  timeline = clutter_animation_get_timeline (self);
+  direction = clutter_timeline_get_direction (timeline);
+
   /* explicitly set the final state of the animation */
   g_hash_table_iter_init (&iter, priv->properties);
   while (g_hash_table_iter_next (&iter, &key, &value))
@@ -143,7 +148,11 @@ clutter_animation_real_completed (ClutterAnimation *self)
       ClutterInterval *interval = value;
       GValue *p_value;
 
-      p_value = clutter_interval_peek_final_value (interval);
+      if (direction == CLUTTER_TIMELINE_FORWARD)
+        p_value = clutter_interval_peek_final_value (interval);
+      else
+        p_value = clutter_interval_peek_initial_value (interval);
+
       g_object_set_property (priv->object, p_name, p_value);
     }
 
@@ -603,6 +612,7 @@ clutter_animation_bind_interval (ClutterAnimation *animation,
  * calls convenient in language bindings.
  *
  * Return value: (transfer none): The animation itself.
+ *
  * Since: 1.0
  */
 ClutterAnimation *
@@ -724,7 +734,7 @@ clutter_animation_update_interval (ClutterAnimation *animation,
 
   if (!clutter_animation_has_property (animation, property_name))
     {
-      g_warning ("Cannot unbind property '%s': the animation has "
+      g_warning ("Cannot update property '%s': the animation has "
                  "no bound property with that name",
                  property_name);
       return;
@@ -734,7 +744,7 @@ clutter_animation_update_interval (ClutterAnimation *animation,
   pspec = g_object_class_find_property (klass, property_name);
   if (!pspec)
     {
-      g_warning ("Cannot bind property '%s': objects of type '%s' have "
+      g_warning ("Cannot update property '%s': objects of type '%s' have "
                  "no such property",
                  property_name,
                  g_type_name (G_OBJECT_TYPE (priv->object)));
@@ -744,7 +754,7 @@ clutter_animation_update_interval (ClutterAnimation *animation,
   if (!g_value_type_compatible (G_PARAM_SPEC_VALUE_TYPE (pspec),
                                 clutter_interval_get_value_type (interval)))
     {
-      g_warning ("Cannot bind property '%s': the interval value of "
+      g_warning ("Cannot update property '%s': the interval value of "
                  "type '%s' is not compatible with the property value "
                  "of type '%s'",
                  property_name,
