@@ -242,7 +242,7 @@ static void
 clutter_behaviour_alpha_notify_unimplemented (ClutterBehaviour *behaviour,
                                               gdouble           alpha_value)
 {
-  g_warning ("ClutterBehaviourClass::alpha_notify not implemented for `%s'",
+  g_warning ("ClutterBehaviourClass::alpha_notify not implemented for '%s'",
              g_type_name (G_TYPE_FROM_INSTANCE (behaviour)));
 }
 
@@ -552,13 +552,16 @@ notify_cb (GObject          *object,
  * @behave: a #ClutterBehaviour
  * @alpha: a #ClutterAlpha or %NULL to unset a previously set alpha
  *
- * Binds @alpha to a #ClutterBehaviour.  The #ClutterAlpha object
+ * Binds @alpha to a #ClutterBehaviour. The #ClutterAlpha object
  * is what makes a behaviour work: for each tick of the timeline
  * used by #ClutterAlpha a new value of the alpha parameter is
  * computed by the alpha function; the value should be used by
  * the #ClutterBehaviour to update one or more properties of the
  * actors to which the behaviour applies.
  *
+ * If @alpha is not %NULL, the #ClutterBehaviour will take ownership
+ * of the #ClutterAlpha instance.
+ *
  * Since: 0.2
  */
 void
