@@ -24,6 +24,7 @@
  *   Robert Bragg <robert@linux.intel.com>
  */
 
+#include <cogl.h>
 #include <cogl-matrix.h>
 
 #include <glib.h>
@@ -87,9 +88,11 @@ cogl_matrix_rotate (CoglMatrix *matrix,
 {
   CoglMatrix rotation;
   CoglMatrix result;
+  float c, s;
+
   angle *= G_PI / 180.0f;
-  float c = cosf (angle);
-  float s = sinf (angle);
+  c = cosf (angle);
+  s = sinf (angle);
 
   rotation.xx = x * x * (1.0f - c) + c;
   rotation.yx = y * x * (1.0f - c) + z * s;
@@ -217,8 +220,8 @@ cogl_matrix_ortho (CoglMatrix *matrix,
                    float right,
                    float bottom,
                    float top,
-                   float near,
-                   float far)
+                   float near_val,
+                   float far_val)
 {
   CoglMatrix ortho;
 
@@ -237,13 +240,13 @@ cogl_matrix_ortho (CoglMatrix *matrix,
   /* column 2 */
   ortho.xz = 0.0;
   ortho.yz = 0.0;
-  ortho.zz = -2.0 / (far - near);
+  ortho.zz = -2.0 / (far_val - near_val);
   ortho.wz = 0.0;
 
   /* column 3 */
   ortho.xw = -(right + left) / (right - left);
   ortho.yw = -(top + bottom) / (top - bottom);
-  ortho.zw = -(far + near) / (far - near);
+  ortho.zw = -(far_val + near_val) / (far_val - near_val);
   ortho.ww = 1.0;
 
   cogl_matrix_multiply (matrix, matrix, &ortho);
