@@ -1,11 +1,9 @@
 /*
- * Clutter COGL
+ * Cogl
  *
- * A basic GL/GLES Abstraction/Utility Layer
+ * An object oriented GL/GLES Abstraction/Utility Layer
  *
- * Authored By Matthew Allum  <mallum@openedhand.com>
- *
- * Copyright (C) 2008 OpenedHand
+ * Copyright (C) 2008,2009 Intel Corporation.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,11 +24,13 @@
 #ifndef __COGL_PROGRAM_H
 #define __COGL_PROGRAM_H
 
+#include "cogl-handle.h"
+
 typedef struct _CoglProgram CoglProgram;
 
 struct _CoglProgram
 {
-  guint              ref_count;
+  CoglHandleObject   _parent;
   GLhandleARB        gl_handle;
 };
 
