@@ -1,11 +1,9 @@
 /*
- * Clutter COGL
+ * Cogl
  *
- * A basic GL/GLES Abstraction/Utility Layer
+ * An object oriented GL/GLES Abstraction/Utility Layer
  *
- * Authored By Matthew Allum  <mallum@openedhand.com>
- *
- * Copyright (C) 2008 OpenedHand
+ * Copyright (C) 2008,2009 Intel Corporation.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -261,6 +259,7 @@ struct _CoglGles2WrapperShader
 
 #define GL_TEXTURE_ENV         0x2300
 #define GL_TEXTURE_ENV_MODE    0x2200
+#define GL_TEXTURE_ENV_COLOR   0x2201
 #define GL_MODULATE            0x2100
 
 #define GL_EXP                 0x8000
@@ -329,7 +328,8 @@ void cogl_wrap_glColorPointer (GLint size, GLenum type, GLsizei stride,
 void cogl_wrap_glNormalPointer (GLenum type, GLsizei stride,
 				const GLvoid *pointer);
 
-void cogl_wrap_glTexEnvi (GLenum target, GLenum pname, GLfloat param);
+void cogl_wrap_glTexEnvi (GLenum target, GLenum pname, GLint param);
+void cogl_wrap_glTexEnvfv (GLenum target, GLenum pname, const GLfloat *params);
 
 void cogl_wrap_glClientActiveTexture (GLenum texture);
 void cogl_wrap_glActiveTexture (GLenum texture);
@@ -340,6 +340,7 @@ void cogl_wrap_glDisableClientState (GLenum array);
 void cogl_wrap_glAlphaFunc (GLenum func, GLclampf ref);
 
 void cogl_wrap_glColor4f (GLclampf r, GLclampf g, GLclampf b, GLclampf a);
+void cogl_wrap_glColor4ub (GLubyte r, GLubyte g, GLubyte b, GLubyte a);
 
 void cogl_wrap_glClipPlanef (GLenum plane, GLfloat *equation);
 
@@ -386,12 +387,14 @@ void _cogl_gles2_clear_cache_for_program (CoglHandle program);
 #define glColorPointer               cogl_wrap_glColorPointer
 #define glNormalPointer              cogl_wrap_glNormalPointer
 #define glTexEnvi                    cogl_wrap_glTexEnvi
+#define glTexEnvfv                   cogl_wrap_glTexEnvfv
 #define glActiveTexture              cogl_wrap_glActiveTexture
 #define glClientActiveTexture        cogl_wrap_glClientActiveTexture
 #define glEnableClientState          cogl_wrap_glEnableClientState
 #define glDisableClientState         cogl_wrap_glDisableClientState
 #define glAlphaFunc                  cogl_wrap_glAlphaFunc
 #define glColor4f                    cogl_wrap_glColor4f
+#define glColor4ub                   cogl_wrap_glColor4ub
 #define glClipPlanef                 cogl_wrap_glClipPlanef
 #define glGetIntegerv                cogl_wrap_glGetIntegerv
 #define glGetFloatv                  cogl_wrap_glGetFloatv
