@@ -31,6 +31,8 @@
 
 #include <string.h>
 
+#include "json-types-private.h"
+
 #include "json-marshal.h"
 #include "json-parser.h"
 
@@ -378,6 +380,7 @@ json_parse_array (JsonParser *parser,
             {
               json_node_free (node);
               json_array_unref (array);
+
               return token;
             }
 
@@ -411,6 +414,7 @@ json_parse_array (JsonParser *parser,
             {
               json_node_free (node);
               json_array_unref (array);
+
               return token;
             }
 
@@ -440,6 +444,8 @@ json_parse_array (JsonParser *parser,
             }
           else
             {
+              json_array_unref (array);
+
               return G_TOKEN_INT;
             }
         }
@@ -475,6 +481,7 @@ json_parse_array (JsonParser *parser,
           break;
 
         default:
+          json_array_unref (array);
           return G_TOKEN_RIGHT_BRACE;
         }
 
@@ -542,6 +549,7 @@ json_parse_object (JsonParser *parser,
             {
               g_free (name);
               json_object_unref (object);
+
               return ':';
             }
           else
@@ -554,6 +562,7 @@ json_parse_object (JsonParser *parser,
       if (!name)
         {
           json_object_unref (object);
+
           return G_TOKEN_STRING;
         }
 
@@ -576,10 +585,11 @@ json_parse_object (JsonParser *parser,
                 json_node_free (node);
 
               json_object_unref (object);
+
               return token;
             }
 
-          json_object_add_member (object, name, node);
+          json_object_set_member (object, name, node);
           node->parent = priv->current_node;
 
           g_signal_emit (parser, parser_signals[OBJECT_MEMBER], 0,
@@ -611,10 +621,11 @@ json_parse_object (JsonParser *parser,
               g_free (name);
               json_node_free (node);
               json_object_unref (object);
+
               return token;
             }
 
-          json_object_add_member (object, name, node);
+          json_object_set_member (object, name, node);
           node->parent = priv->current_node;
           
           g_signal_emit (parser, parser_signals[OBJECT_MEMBER], 0,
@@ -641,6 +652,8 @@ json_parse_object (JsonParser *parser,
             }
           else
             {
+              json_object_unref (object);
+
               return G_TOKEN_INT;
             }
         }
@@ -676,12 +689,13 @@ json_parse_object (JsonParser *parser,
           break;
 
         default:
+          json_object_unref (object);
           return G_TOKEN_SYMBOL;
         }
 
       if (node)
         {
-          json_object_add_member (object, name, node);
+          json_object_set_member (object, name, node);
           node->parent = priv->current_node;
           
           g_signal_emit (parser, parser_signals[OBJECT_MEMBER], 0,
@@ -948,8 +962,8 @@ json_parser_load_from_data (JsonParser   *parser,
                         if (symbols[i].token == expected_token)
                           symbol_name = symbol_names + symbols[i].name_offset;
 
-                      if (msg)
-                        msg = g_strconcat ("e.g. `", symbol_name, "'", NULL);
+                      if (!msg)
+                        msg = g_strconcat ("e.g. '", symbol_name, "'", NULL);
                     }
 
                   if (scanner->token > JSON_TOKEN_INVALID &&
@@ -976,16 +990,7 @@ json_parser_load_from_data (JsonParser   *parser,
                   g_propagate_error (error, parser->priv->last_error);
                   parser->priv->last_error = NULL;
                 }
-#if 0
-              /* we set a generic error here; the message from
-               * GScanner is relayed in the ::error signal
-               */
-              g_set_error (error, JSON_PARSER_ERROR,
-                           JSON_PARSER_ERROR_PARSE,
-                           "Invalid token `%s' found: expecting %s",
-                           symbol_name ? symbol_name : "???",
-                           msg ? msg : "unknown");
-#endif
+
               retval = FALSE;
 
               g_free (msg);
