@@ -15,9 +15,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- *
- *
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 #include "config.h"
 
@@ -61,8 +61,6 @@ clutter_backend_osx_post_parse (ClutterBackend  *backend,
    */
   NSOpenGLPixelFormatAttribute attrs[] = {
     NSOpenGLPFADoubleBuffer,
-    NSOpenGLPFADepthSize, 24,
-    NSOpenGLPFAStencilSize, 8,
     0
   };
   self->pixel_format = [[NSOpenGLPixelFormat alloc] initWithAttributes:attrs];
@@ -70,12 +68,8 @@ clutter_backend_osx_post_parse (ClutterBackend  *backend,
                    initWithFormat: self->pixel_format
                      shareContext: nil];
 
-  /* Enable vblank sync - http://developer.apple.com/qa/qa2007/qa1521.html */
-  #ifdef MAC_OS_X_VERSION_10_5
-	const int sw = 1;
-  #else
-    const long sw = 1;
-  #endif
+  /* Enable vblank sync - http://developer.apple.com/qa/qa2007/qa1521.html*/
+  const long sw = 1;
   [self->context setValues:&sw forParameter: NSOpenGLCPSwapInterval];
 
   /* FIXME: move the debugging bits to cogl */
@@ -102,12 +96,12 @@ clutter_backend_osx_get_features (ClutterBackend *backend)
   return CLUTTER_FEATURE_STAGE_MULTIPLE|CLUTTER_FEATURE_STAGE_USER_RESIZE;
 }
 
-static ClutterStageWindow*
+static ClutterActor*
 clutter_backend_osx_create_stage (ClutterBackend  *backend,
                                   ClutterStage    *wrapper,
                                   GError         **error)
 {
-  ClutterStageWindow *impl;
+  ClutterActor *impl;
 
   CLUTTER_NOTE (BACKEND, "create_stage: wrapper=%p", wrapper);
 
