@@ -1,8 +1,6 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#include <math.h>
-
 #include <glib.h>
 #include <gmodule.h>
 
@@ -40,18 +38,12 @@ static const gchar *test_behaviour =
 "    \"loop\" : true"
 "  },"
 "  {"
-"    \"id\" : \"sine-alpha\","
-"    \"type\" : \"ClutterAlpha\","
-"    \"function\" : \"sine_alpha\","
-"    \"timeline\" : \"main-timeline\""
-"  },"
-"  {"
 "    \"id\"          : \"path-behaviour\","
 "    \"type\"        : \"ClutterBehaviourPath\","
 "    \"path\"        : \"M 50 50 L 100 100\","
 "    \"alpha\"       : {"
 "      \"timeline\" : \"main-timeline\","
-"      \"function\" : \"double_ramp_alpha\""
+"      \"mode\"     : \"linear\""
 "    }"
 "  },"
 "  {"
@@ -60,7 +52,10 @@ static const gchar *test_behaviour =
 "    \"angle-start\" : 0.0,"
 "    \"angle-end\"   : 360.0,"
 "    \"axis\"        : \"y-axis\","
-"    \"alpha\"       : \"sine-alpha\""
+"    \"alpha\"       : {"
+"      \"timeline\" : \"main-timeline\","
+"      \"mode\"     : \"ease-in-sine\""
+"    }"
 "  },"
 "  {"
 "    \"id\"            : \"fade-behaviour\","
@@ -68,36 +63,12 @@ static const gchar *test_behaviour =
 "    \"opacity-start\" : 255,"
 "    \"opacity-end\"   : 0,"
 "    \"alpha\"         : {"
-"      \"id\"       : \"fade-alpha\","
-"      \"type\"     : \"ClutterAlpha\","
 "      \"timeline\" : \"main-timeline\","
-"      \"mode\"     : \"linear\""
+"      \"mode\"     : \"easeOutCubic\""
 "    }"
 "  }"
 "]";
 
-gdouble
-sine_alpha (ClutterAlpha *alpha,
-            gpointer      dummy G_GNUC_UNUSED)
-{
-  ClutterTimeline *timeline = clutter_alpha_get_timeline (alpha);
-
-  return sin (clutter_timeline_get_progress (timeline) * G_PI);
-}
-
-gdouble
-double_ramp_alpha (ClutterAlpha *alpha,
-                   gpointer      dummy G_GNUC_UNUSED)
-{
-  ClutterTimeline *timeline = clutter_alpha_get_timeline (alpha);
-  gdouble progress = clutter_timeline_get_progress (timeline);
-
-  if (progress >= 0.5)
-    return 1.0 - progress;
-
-  return progress;
-}
-
 static gboolean
 blue_button_press (ClutterActor       *actor,
                    ClutterButtonEvent *event,
@@ -136,7 +107,6 @@ test_script_main (int argc, char *argv[])
 {
   GObject *stage, *blue_button, *red_button;
   GError *error = NULL;
-  gchar *file;
   gint res;
 
   clutter_init (&argc, &argv);
@@ -153,21 +123,17 @@ test_script_main (int argc, char *argv[])
       g_object_unref (script);
       return EXIT_FAILURE;
     }
-
-  file = g_build_filename (TESTS_DATADIR, "test-script.json", NULL);
-  clutter_script_load_from_file (script, file, &error);
+  
+  clutter_script_load_from_file (script, "test-script.json", &error);
   if (error)
     {
       g_print ("*** Error:\n"
                "***   %s\n", error->message);
       g_error_free (error);
       g_object_unref (script);
-      g_free (file);
       return EXIT_FAILURE;
     }
 
-  g_free (file);
-
   merge_id = clutter_script_load_from_data (script, test_unmerge, -1, &error);
   if (error)
     {
