@@ -1,8 +1,6 @@
 #!/bin/sh
 
-UNIT_TEST=$1
-
-shift
+UNIT_TEST=`basename $0`
 
 echo "Running ./test-interactive $UNIT_TEST $@"
 echo ""
